---

name: Bug Report
about: Create a bug report to help us improve GETTSIM
title: "BUG:"
labels: "bug"
assignees: ''


---

### Bug description

A clear and concise description of what the bug is.

- [ ] I have checked that this issue has not already been reported.

- [ ] I have confirmed this bug exists on the latest version of GETTSIM.

- [ ] (optional) I have confirmed this bug exists on the `main` branch of GETTSIM.

---

**Note**: Please read [this
guide](https://matthewrocklin.com/blog/work/2018/02/28/minimal-bug-reports) detailing
how to provide the necessary information for us to reproduce your bug.

#### Code Sample, a copy-pastable example

```python
# Your code here
```

#### Problem description

Explain **why** the current behaviour is a problem and why the expected output is a
better solution.

#### Expected Output
